==> vokoscreen_1.9.0.orig.tar.gz: vokoscreen-1.9.0/language/vokoscreen_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>傳送最後一個影片</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>傳送一個或多個影片</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>傳送</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>您會看到影片當作附加檔案</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>選擇一個或多個檔案</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>沒有視窗邊框</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>視窗邊框</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>網路攝影機</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>裝置忙碌中</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>區域</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音訊</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>預設值</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>編碼器</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要錄製滑鼠游標</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>影片路徑</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>開始錄製時最小化 Vokoscreen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>傳送</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>錄製時間</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>大小(KB)</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>錄製螢幕大小</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>設定影格率</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>開啟目錄</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒數計時</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>播放最後一個影片</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>傳送影片</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>選取一個或多個裝置</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>實際的影格率</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>裝置 %1 忙碌中</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation>您設定的影格率太高了</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>裝置忙碌中</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>傳送最後一個影片</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>傳送一個或多個影片</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>傳送</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>您會看到影片當作附加檔案</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>選擇一個或多個檔案</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>視窗邊框</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>裝置忙碌中</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>區域</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音訊</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>預設值</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>編碼器</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要錄製滑鼠游標</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>影片路徑</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>開始錄製時最小化 Vokoscreen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>傳送</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>錄製時間</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>大小(KB)</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>錄製螢幕大小</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>設定影格率</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>開啟目錄</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒數計時</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>播放最後一個影片</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>傳送影片</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>選取一個或多個裝置</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>實際的影格率</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>網路攝影機</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
